@@ -6,16 +6,14 @@ use warnings;
 use Scalar::Util;
 
 use overload
-  '""' => sub {
-            return Scalar::Util::refaddr($_[0]) if (caller)[0] eq 'NEXT';
-            return shift->stringify_self; },
+  '""' => sub { return shift->stringify_self; },
   fallback => 1;
 
 sub stringify_self {
         my $self = shift;
         my @cols = $self->columns('Stringify');
         @cols = $self->primary_column unless @cols;
-        my $ret = join "/", map { $self->get_column($_) } @cols;
+        my $ret = join "/", map { $self->get_column($_) || '' } @cols;
         return $ret || ref $self;
 }
 
