@@ -3,14 +3,12 @@ package DBIx::Class::Relationship::Accessor;
 use strict;
 use warnings;
 
-sub add_relationship {
-  my ($class, $rel, @rest) = @_;
-  my $ret = $class->next::method($rel => @rest);
-  my $rel_obj = $class->_relationships->{$rel};
-  if (my $acc_type = $rel_obj->{attrs}{accessor}) {
+sub register_relationship {
+  my ($class, $rel, $info) = @_;
+  if (my $acc_type = $info->{attrs}{accessor}) {
     $class->add_relationship_accessor($rel => $acc_type);
   }
-  return $ret;
+  $class->next::method($rel => $info);
 }
 
 sub add_relationship_accessor {
@@ -31,9 +29,9 @@ sub add_relationship_accessor {
       }
     };
   } elsif ($acc_type eq 'filter') {
-    $class->throw("No such column $rel to filter")
+    $class->throw_exception("No such column $rel to filter")
        unless $class->has_column($rel);
-    my $f_class = $class->_relationships->{$rel}{class};
+    my $f_class = $class->relationship_info($rel)->{class};
     $class->inflate_column($rel,
       { inflate => sub {
           my ($val, $self) = @_;
@@ -41,7 +39,7 @@ sub add_relationship_accessor {
         },
         deflate => sub {
           my ($val, $self) = @_;
-          $self->throw("$val isn't a $f_class") unless $val->isa($f_class);
+          $self->throw_exception("$val isn't a $f_class") unless $val->isa($f_class);
           return ($val->_ident_values)[0];
             # WARNING: probably breaks for multi-pri sometimes. FIXME
         }
@@ -51,7 +49,7 @@ sub add_relationship_accessor {
     $meth{$rel} = sub { shift->search_related($rel, @_) };
     $meth{"add_to_${rel}"} = sub { shift->create_related($rel, @_); };
   } else {
-    $class->throw("No such relationship accessor type $acc_type");
+    $class->throw_exception("No such relationship accessor type $acc_type");
   }
   {
     no strict 'refs';
