@@ -8,7 +8,7 @@ SQL::Translator::Producer::DBIx::Class::File - DBIx::Class file producer
 
   use SQL::Translator;
 
-  my $t = SQL::Translator->new( parser => '...',
+  my $t = SQL::Translator->new( parser => '...', 
                                 producer => 'DBIx::Class::File' );
   print $translator->translate( $file );
 
@@ -16,27 +16,15 @@ SQL::Translator::Producer::DBIx::Class::File - DBIx::Class file producer
 
 Creates a DBIx::Class::Schema for use with DBIx::Class
 
-=head1 FURTHER QUESTIONS?
-
-Check the list of L<additional DBIC resources|DBIx::Class/GETTING HELP/SUPPORT>.
-
-=head1 COPYRIGHT AND LICENSE
-
-This module is free software L<copyright|DBIx::Class/COPYRIGHT AND LICENSE>
-by the L<DBIx::Class (DBIC) authors|DBIx::Class/AUTHORS>. You can
-redistribute it and/or modify it under the same terms as the
-L<DBIx::Class library|DBIx::Class/COPYRIGHT AND LICENSE>.
-
 =cut
 
 use strict;
-our ($VERSION, $DEBUG, $WARN);
+use vars qw[ $VERSION $DEBUG $WARN ];
 $VERSION = '0.1';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use SQL::Translator::Schema::Constants;
 use SQL::Translator::Utils qw(header_comment);
-use DBIx::Class::_Util 'dump_value';
 
 ## Skip all column type translation, as we want to use whatever the parser got.
 
@@ -60,7 +48,7 @@ sub produce
     my $output         = '';
 
     # Steal the XML producers "prefix" arg for our namespace?
-    my $dbixschema     = $translator->producer_args()->{prefix} ||
+    my $dbixschema     = $translator->producer_args()->{prefix} || 
         $schema->name || 'My::Schema';
     my $pkclass = $parser2PK{$translator->parser_type} || '';
 
@@ -93,7 +81,7 @@ __PACKAGE__->table('${tname}');
 
 };
 
-        my @fields = map
+        my @fields = map 
         { { $_->name  => {
             name              => $_->name,
             is_auto_increment => $_->is_auto_increment,
@@ -108,9 +96,13 @@ __PACKAGE__->table('${tname}');
         $output .= "\n__PACKAGE__->add_columns(";
         foreach my $f (@fields)
         {
+            local $Data::Dumper::Terse = 1;
             $output .= "\n    '" . (keys %$f)[0] . "' => " ;
-            ( my $colinfo = dump_value( (values %$f)[0] ) ) =~ s/^/    /mg;
-            $colinfo =~ s/^\s*|\s*$//g;
+            my $colinfo = 
+                Data::Dumper->Dump([values %$f],
+                                   [''] # keys   %$f]
+                                   );
+            chomp($colinfo);
             $output .= $colinfo . ",";
         }
         $output .= "\n);\n";
@@ -125,16 +117,17 @@ __PACKAGE__->table('${tname}');
 
         foreach my $cont ($table->get_constraints)
         {
+#            print Data::Dumper::Dumper($cont->type);
             if($cont->type =~ /foreign key/i)
             {
-#                 $output .= "\n__PACKAGE__->belongs_to('" .
+#                 $output .= "\n__PACKAGE__->belongs_to('" . 
 #                     $cont->fields->[0]->name . "', '" .
 #                     "${dbixschema}::" . $cont->reference_table . "');\n";
 
-                $tableextras{$table->name} .= "\n__PACKAGE__->belongs_to('" .
+                $tableextras{$table->name} .= "\n__PACKAGE__->belongs_to('" . 
                     $cont->fields->[0]->name . "', '" .
                     "${dbixschema}::" . $cont->reference_table . "');\n";
-
+                
                 my $other = "\n__PACKAGE__->has_many('" .
                     "get_" . $table->name. "', '" .
                     "${dbixschema}::" . $table->name. "', '" .
@@ -149,7 +142,7 @@ __PACKAGE__->table('${tname}');
     foreach my $to (keys %tableoutput)
     {
         $output .= $tableoutput{$to};
-        $schemaoutput .= "\n__PACKAGE__->register_class('${to}', '${dbixschema}::${to}');\n";
+        $schemaoutput .= "\n__PACKAGE__->register_class('${to}', '${dbixschema}::${to}');\n"; 
     }
 
     foreach my $te (keys %tableextras)
