@@ -1,10 +1,7 @@
-package # hide from PAUSE 
-    DBICTest::Schema::OneKey;
+package DBICTest::Schema::OneKey;
 
 use base 'DBIx::Class::Core';
 
-__PACKAGE__->load_components('PK::Auto');
-
 DBICTest::Schema::OneKey->table('onekey');
 DBICTest::Schema::OneKey->add_columns(
   'id' => {
